@@ -5,6 +5,7 @@ import jinja2
 import logging
 import os
 import pandas as pd
+import platform
 import random
 import socket
 import sys
@@ -14,8 +15,16 @@ from builtins import map, str
 from contextlib import closing
 from logging import ERROR as LOG_ERROR
 from threading import Timer
+from werkzeug.routing import Map
 
-from flask import Flask, jsonify, redirect, render_template, request, url_for
+from flask import (
+    Flask,
+    jsonify,
+    redirect,
+    render_template,
+    request,
+    url_for as flask_url_for,
+)
 from flask.testing import FlaskClient
 
 import requests
@@ -151,17 +160,33 @@ class DtaleFlask(Flask):
                     )
                 )
             return fix_url_path("{}/{}".format(self.app_root, args[0]))
-        return url_for(endpoint, *args, **kwargs)
+        major, minor, revision = [int(i) for i in platform.python_version_tuple()]
+        if major == 2 or (major == 3 and minor < 7):
+            return flask_url_for(endpoint, *args, **kwargs)
+        return Flask.url_for(self, endpoint, *args, **kwargs)
 
     def _override_routes(self, rule):
         try:
             routes_to_remove = [r for r in self.url_map._rules if r.rule == rule]
             if routes_to_remove:
-                self.url_map._rules = [
-                    r
+                updated_rules = [
+                    r.empty()
                     for r in self.url_map._rules
                     if not contains_route(routes_to_remove, r)
                 ]
+                self.url_map = Map(
+                    rules=updated_rules,
+                    default_subdomain=self.url_map.default_subdomain,
+                    charset=self.url_map.charset,
+                    strict_slashes=self.url_map.strict_slashes,
+                    merge_slashes=self.url_map.merge_slashes,
+                    redirect_defaults=self.url_map.redirect_defaults,
+                    converters=self.url_map.converters,
+                    sort_parameters=self.url_map.sort_parameters,
+                    sort_key=self.url_map.sort_key,
+                    encoding_errors=self.url_map.encoding_errors,
+                    host_matching=self.url_map.host_matching,
+                )
 
             self.url_map._remap = True
             self.url_map.update()
