@@ -46,6 +46,9 @@ def validate_allow_cell_edits(ctx, param, value):
     help='flag to show "Fork Me On GitHub" link in upper right-hand corner of the app',
 )
 @click.option("--app-root", type=str)
+@click.option(
+    "--hide-drop-rows", is_flag=True, help='flag to hide "Drop Rows" button from users'
+)
 @click.option(
     "--theme",
     default="light",
@@ -66,6 +69,23 @@ def validate_allow_cell_edits(ctx, param, value):
     "--hide-columns",
     help="Comma-separated string of column names you would like hidden on load",
 )
+@click.option(
+    "--query-engine",
+    default="python",
+    type=click.Choice(["python", "numexpr"]),
+    help='query engine you would like used for D-Tale, the default is "python"',
+)
+@click.option(
+    "--sort",
+    help=(
+        "Comma-separated string of pipe-separated column names/sort directions you would like applied on load. "
+        "EX: col1|ASC,col2|DESC"
+    ),
+)
+@click.option(
+    "--locked",
+    help="Comma-separated string of column names you would like locked on the left-hand side of your grid on load",
+)
 @setup_loader_options()
 @click.option("--log", "logfile", help="Log file name")
 @click.option(
@@ -87,6 +107,7 @@ def main(
     hide_shutdown=None,
     github_fork=None,
     app_root=None,
+    hide_drop_rows=None,
     **kwargs
 ):
     """
@@ -111,6 +132,12 @@ def main(
     kwargs["hide_columns"] = (
         kwargs["hide_columns"].split(",") if kwargs.get("hide_columns") else None
     )
+    kwargs["sort"] = (
+        [tuple(sort.split("|")) for sort in kwargs["sort"].split(",")]
+        if kwargs.get("sort")
+        else None
+    )
+    kwargs["locked"] = kwargs["locked"].split(",") if kwargs.get("locked") else None
     show(
         host=host,
         port=int(port or find_free_port()),
@@ -124,6 +151,7 @@ def main(
         hide_shutdown=hide_shutdown,
         github_fork=github_fork,
         app_root=app_root,
+        hide_drop_rows=hide_drop_rows,
         **kwargs
     )
 
